/*

  This file is a part of GRALESHELL, a program to facilitate the simulation
  and inversion of gravitational lenses, based on the GRALE library.

  Copyright (C) 2008-2012 Jori Liesenborgs

  Contact: jori.liesenborgs@gmail.com
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.
  
  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
  
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  
*/

#include "graleshellimageplane.h"
#include "graleshellinstance.h"
#include <shellp/iosystem.h>

#include "debugnew.h"

using namespace shellp;

GraleShellImagePlane::GraleShellImagePlane(grale::GravitationalLens *l, grale::SourcePlane *s) : grale::ImagePlane(l,s)
{
	GraleShellInstance *gsinst = (GraleShellInstance *)ShellInstance::getInstance();

	iosys = gsinst->getIOSystem();
	prevpct = -1;
}

GraleShellImagePlane::~GraleShellImagePlane()
{
}

void GraleShellImagePlane::setFeedbackStatus(const std::string &msg)
{
	iosys->writeOutputLine(msg);
}

void GraleShellImagePlane::setFeedbackPercentage(int pct)
{
	if (pct == prevpct || pct > 100 || pct < 0)
		return;
	prevpct = pct;
	iosys->setPercentageFeedback(pct);
}

